from .aws_s3_abort_multipart_upload_request import AWSs3AbortMultipartUploadRequest as AWSs3AbortMultipartUploadRequest
from .aws_s3_abort_multipart_upload_response import AWSs3AbortMultipartUploadResponse as AWSs3AbortMultipartUploadResponse
from .aws_s3_complete_multipart_upload_request import AWSs3CompleteMultipartUploadRequest as AWSs3CompleteMultipartUploadRequest
from .aws_s3_complete_multipart_upload_response import AWSs3CompleteMultipartUploadResponse as AWSs3CompleteMultipartUploadResponse
from .aws_s3_copy_source import AWSs3CopySource
from .aws_s3_copy_object_options import AWSs3CopyObjectOptions
from .aws_s3_copy_object_response import AWSs3CopyObjectResponse
from .aws_s3_create_multipart_upload_request import AWSs3CreateMultipartUploadRequest as AWSs3CreateMultipartUploadRequest
from .aws_s3_create_multipart_upload_response import AWSs3CreateMultipartUploadResponse as AWSs3CreateMultipartUploadResponse
from .aws_s3_delete_bucket_request import AWSS3DeleteBucketRequest as AWSS3DeleteBucketRequest
from .aws_s3_delete_bucket_response import AWSS3DeleteBucketReponse as AWSS3DeleteBucketReponse
from .aws_s3_delete_bucket_tagging_options import AWSs3DeleteBucketTaggingOptions
from .aws_s3_delete_bucket_tagging_response import AWSs3DeleteBucketTaggingResponse
from .aws_s3_delete_object_request import AWSS3DeleteObjectRequest as AWSS3DeleteObjectRequest
from .aws_s3_delete_object_response import AWSS3DeleteObjectResponse as AWSS3DeleteObjectResponse
from .aws_s3_delete_object_tagging_options import AWSs3DeleteObjectTaggingOptions
from .aws_s3_delete_object_tagging_response import AWSs3DeleteObjectTaggingResponse
from .aws_s3_delete_objects_options import AWSs3DeleteObjectsOptions
from .aws_s3_delete_objects_response import AWSs3DeleteObjectsResponse
from .aws_s3_generate_presigned_post_options import AWSs3GeneratePresignedPostOptions
from .aws_s3_generate_presigned_post_response import AWSs3GeneratePresignedPostResponse
from .aws_s3_generate_presigned_url_options import AWSs3GeneratePresignedURLOptions
from .aws_s3_generate_presigned_url_response import AWSs3GeneratePresignedURLResponse
from .aws_s3_get_bucket_tagging_options import AWSs3GetBucketTaggingOptions
from .aws_s3_get_bucket_tagging_response import AWSs3GetBucketTaggingResponse
from .aws_s3_get_object_request import AWSS3GetObjectRequest as AWSS3GetObjectRequest
from .aws_s3_get_object_response import AWSS3GetObjectResponse as AWSS3GetObjectResponse
from .aws_s3_get_object_tagging_options import AWSs3GetObjectTaggingOptions
from .aws_s3_get_object_tagging_response import AWSs3GetObjectTaggingResponse
from .aws_s3_list_buckets import AWSs3ListBucketsResponse
from .aws_s3_list_directory_buckets_options import AWSs3ListDirectoryBucketsOptions
from .aws_s3_list_directory_buckets_response import AWSs3ListDirectoryBucketsResponse
from .aws_s3_list_objects_request import AWSS3ListObjectsRequest as AWSS3ListObjectsRequest
from .aws_s3_list_objects_response import AWSS3ListObjectsResponse as AWSS3ListObjectsResponse
from .aws_s3_list_object_versions_options import AWSs3ListObjectVersionsOptions
from .aws_s3_list_object_versions_response import AWSs3ListObjectVersionsResponse
from .aws_s3_list_parts_request import AWSs3ListPartsRequest as AWSs3ListPartsRequest
from .aws_s3_list_parts_response import AWSs3ListPartsResponse as AWSs3ListPartsResponse
from .aws_s3_list_multipart_uploads_request import AWSs3ListMultipartUploadsRequest as AWSs3ListMultipartUploadsRequest
from .aws_s3_list_multipart_uploads_response import AWSs3ListMultipartUploadsResponse
from .aws_s3_multipart_upload import AWSs3MultipartUpload
from .aws_s3_object import AWSs3Object
from .aws_s3_put_bucket_tagging_options import AWSs3PutBucketTaggingOptions
from .aws_s3_put_bucket_tagging_response import AWSs3PutBucketTaggingResponse
from .aws_s3_put_bucket_versioning_options import AWSs3PutBucketVersioningOptions
from .aws_s3_put_bucket_versioning_response import AWSs3PutBucketVersioningResponse
from .aws_s3_put_object_request import AWSS3PutObjectRequest as AWSS3PutObjectRequest
from .aws_s3_put_object_response import AWSS3PutObjectResponse as AWSS3PutObjectResponse
from .aws_s3_put_object_tagging_options import AWSs3PutObjectTaggingOptions
from .aws_s3_put_object_tagging_response import AWSs3PutObjectTaggingResponse
from .aws_s3_streaming_body import AWSS3StreamingBody as AWSS3StreamingBody
from .aws_s3_tag import AWSs3Tag
from .aws_s3_transfer_allowed_upload_args import AWSs3TransferAllowedUploadArgs
from .aws_s3_transfer_config_options import AWSs3TransferConfigOptions
from .aws_s3_upload_part_copy_request import AWSs3UploadPartCopyRequest as AWSs3UploadPartCopyRequest
from .aws_s3_upload_part_copy_response import AWSs3UploadPartCopyResponse as AWSs3UploadPartCopyResponse
from .aws_s3_upload_part_request import AWSs3UploadPartRequest as AWSs3UploadPartRequest
from .aws_s3_upload_part_response import AWSs3UploadPartResponse as AWSs3UploadPartResponse